@@ -1,24 +1,9 @@
 /*
+    SPDX-FileCopyrightText: 2003 Razvan Cojocaru <razvanco@gmx.net>
+    Most of the code in this file is a modified version of code from
+    Pabs' GPL chmdeco project, credits and thanks go to him.
 
-  Copyright (C) 2003  Razvan Cojocaru <razvanco@gmx.net>
-  Most of the code in this file is a modified version of code from
-  Pabs' GPL chmdeco project, credits and thanks go to him.
-
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 inline unsigned short UINT16ARRAY(const void *x)
