@@ -1,21 +1,9 @@
-/* Expand one page of fax data
-   Copyright (C) 1990, 1995  Frank D. Cringle.
-
-This file is part of viewfax - g3/g4 fax processing software.
-
-viewfax is free software; you can redistribute it and/or modify it
-under the terms of the GNU General Public License as published by the
-Free Software Foundation; either version 2 of the License, or (at your
-option) any later version.
-
-This program is distributed in the hope that it will be useful, but
-WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA. */
+/*
+    Expand one page of fax data
+    This file is part of viewfax - g3/g4 fax processing software.
+    SPDX-FileCopyrightText: 1990, 1995  Frank D. Cringle.
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "faxexpand.h"
 
