@@ -15,6 +15,8 @@
 
 #include <QMutex>
 
+#include <unordered_map>
+
 #include "config-okular-poppler.h"
 #include "core/annotations.h"
 
@@ -35,6 +37,9 @@ private:
     Poppler::Document *ppl_doc;
     QMutex *mutex;
     QHash<Okular::Annotation *, Poppler::Annotation *> *annotationsOnOpenHash;
+#ifdef HAVE_POPPLER_21_10
+    std::unordered_map<Okular::StampAnnotation *, std::unique_ptr<Poppler::AnnotationAppearance>> deletedStampsAnnotationAppearance;
+#endif
 };
 
 #endif
