@@ -16,7 +16,7 @@
 class PopplerCertificateInfo : public Okular::CertificateInfo
 {
 public:
-    PopplerCertificateInfo(const Poppler::CertificateInfo &info);
+    explicit PopplerCertificateInfo(const Poppler::CertificateInfo &info);
     ~PopplerCertificateInfo() override;
 
     bool isNull() const override;
@@ -42,7 +42,7 @@ private:
 class PopplerSignatureInfo : public Okular::SignatureInfo
 {
 public:
-    PopplerSignatureInfo(const Poppler::SignatureValidationInfo &info);
+    explicit PopplerSignatureInfo(const Poppler::SignatureValidationInfo &info);
     ~PopplerSignatureInfo() override;
 
     SignatureStatus signatureStatus() const override;
